@@ -39,14 +39,27 @@ def updateACL(assetName,writers = [],all_users_can_read = True,readers = []):
 
 #Function for updating all assets under a given folder level in GEE
 def batchUpdateAcl(folder,writers = [],all_users_can_read = True,readers = []):
-    allImages = walkFolders(folder)
-
-    for image in allImages:
-        print( 'Updating acl for:',image)
+    # Update ACL for folders first, then find all images within them.
+    assets = ee.data.listAssets({'parent': folder})['assets']
+    folders = [a for a in assets if a['type'] == 'FOLDER']
+    for subFolder in folders:
+        print( 'Updating acl for:', subFolder)
         try:
-            updateACL(image,writers ,all_users_can_read ,readers)
+            updateACL(subFolder['id'], writers, all_users_can_read, readers)
         except:
-            print( 'Could not update',image)
+            print('Could not update', subFolder)
+    
+    allImages = walkFolders(folder)
+    for image in allImages:
+        print( 'Updating acl for:', image)
+        try:
+            updateACL(image, writers, all_users_can_read, readers)
+        except:
+            print( 'Could not update', image)
+
+    
+       
+   
 
 #############################################################################################
 # Functions for copying, deleting, etc. assets
@@ -76,6 +89,30 @@ def batchCopy(fromFolder,toFolder,outType = 'imageCollection'):
         except:
             print( out,'Error: May already exist')
 
+def copyByName(fromFolder, toFolder, nameIdentifier, outType = 'imageCollection'):
+
+    if outType == 'imageCollection':
+        create_image_collection(toFolder)
+    elif outType == 'tables':
+        verify_path(toFolder)
+
+    if toFolder[-1] == '/':
+        toFolder = toFolder[:-1]
+
+    if outType == 'imageCollection':
+        images = walkFolders(fromFolder)
+    elif outType == 'tables':
+        images = walkFoldersTables(fromFolder)
+    #print( images)
+
+    for image in images:
+        if nameIdentifier in image:
+            out = toFolder +'/'+ base(image)
+            print( out)
+            try:
+                ee.data.copyAsset(image,out)
+            except:
+                print( out,'Error: May already exist')
 #---------------------------------------------------------------------------------------------
 
 def moveImages(images,toFolder):
